@@ -61,7 +61,7 @@ class tdcoa:
     systemspath = ''
     filesetpath = ''
     outputpath = ''
-    version = "0.3.9.7.7"
+    version = "0.3.9.7.8"
     skip_dbs = False    # skip ALL dbs connections / executions
     manual_run = False  # skip dbs executions in execute_run() but not upload_to_transcend()
                         # also skips /*{{save:}}*/ special command
@@ -84,7 +84,6 @@ class tdcoa:
         self.secretpath = os.path.join(self.approot, secrets)
         self.systemspath = os.path.join(self.approot, systems)
         self.refresh_defaults = refresh_defaults
-        self.skip_dbs = skip_dbs
 
         self.utils = Utils(self.version)  # utilities class. inherits Logger class
 
@@ -101,7 +100,7 @@ class tdcoa:
 
         # filesets.yaml is validated at download time
 
-        self.reload_config()
+        self.reload_config(skip_dbs=skip_dbs)
         if os.path.exists(self.filesetpath) and os.path.exists(self.systemspath):
             self.update_sourcesystem_yaml()
 
@@ -133,7 +132,7 @@ class tdcoa:
         self.utils.log('Updated the Sourcesystem yaml file with all the fileset entries in the filesets.yaml file')
 
 
-    def reload_config(self, configpath='', secretpath='', systemspath='', refresh_defaults=False):
+    def reload_config(self, configpath='', secretpath='', systemspath='', refresh_defaults=False, skip_dbs=False):
         """Reloads configuration YAML files (config & secrets) used as
         process driver.  This will also perform any local environment checks,
         such as creating missing folders (download|sql|run|output), change
@@ -266,27 +265,21 @@ class tdcoa:
         # check and set required Settings
         self.utils.log('loading dictionary', 'settings')
         self.settings = configyaml['settings']
+        if skip_dbs: self.settings['skip_dbs'] = 'True'
         self.utils.check_setting(self.settings,
                            required_item_list=['githost', 'gitfileset', 'gitmotd', 'localfilesets',
-                                               'run_non_fileset_folders', 'gui_show_dev_filesets', 'python_call'],
+                                               'run_non_fileset_folders', 'gui_show_dev_filesets',
+                                                'python_call','skip_dbs'],
                            defaults=['https://raw.githubusercontent.com/tdcoa/sql/master/',
                                      'filesets.yaml',
                                      'motd.txt',
                                      '{download}/filesets.yaml',
                                      'True',
                                      'False',
-                                     'python'])
+                                     'python','False'])
 
-        # add skip_dbs back in as silent (unlisted) option
-        # TODO: a) move validate_boolean() from tdgui to utils
-        #       b) re-point tdgui.validate_boolean to validate_boolean
-        #       c) wrap all text-as-boolean in tdcoa with utils.validate_boolean
-        #       d) move tdcoa self.skip_dbs back into self.settings['skip_dbs'] for simplicity
-        if 'skip_dbs' in self.settings:
-            if self.settings['skip_dbs'].strip().lower() == 'true':
-                self.skip_dbs = True
-            else:
-                self.skip_dbs = False
+        if self.utils.validate_boolean(self.settings['skip_dbs'],'bool'):
+            self.utils.log('SKIP_DBS == TRUE, emulating all database connections', warning=True)
 
         self.filesetpath = self.settings['localfilesets']
 
@@ -929,6 +922,7 @@ class tdcoa:
         # make output directory for execution output and other collateral
         runpath = os.path.join(self.approot, self.folders['run'])
         outputpath = self.make_output_folder(name)
+        skip_dbs = self.utils.validate_boolean(self.settings['skip_dbs'],'bool')
 
         # create hidden file containing last run's output -- to remain in the root folder
         with open(os.path.join(self.approot, '.last_run_output_path.txt'), 'w') as lastoutput:
@@ -1002,7 +996,7 @@ class tdcoa:
                                         conntype=self.systems[sysname]['driver'],
                                         encryption=self.systems[sysname]['encryption'],
                                         system=self.systems[sysname],
-                                        skip = self.skip_dbs)  # <------------------------------- Connect to the database
+                                        skip = skip_dbs)  # <------------------------------- Connect to the database
 
                                     # loop thru all sql files:
                                     for coasqlfile in sorted(coasqlfiles):
@@ -1025,7 +1019,7 @@ class tdcoa:
                                                 sql = sqlcmd.pop('sql', '')
 
 
-                                                df = self.utils.open_sql(conn, sql, skip = self.skip_dbs)  # <--------------------- Run SQL
+                                                df = self.utils.open_sql(conn, sql, skip = skip_dbs)  # <--------------------- Run SQL
                                                 csvfile=''
                                                 csvfile_exists=False
 
@@ -1045,7 +1039,7 @@ class tdcoa:
                                                     # Col names will be merged upon save
                                                     col_names = []
                                                     if conn['type'] not in ('sqlalchemy', 'teradataml'):
-                                                        col_names = self.utils.open_sql(conn, sql, columns=True, skip = self.skip_dbs)
+                                                        col_names = self.utils.open_sql(conn, sql, columns=True, skip = skip_dbs)
 
                                                     # once built, append output folder, SiteID on the front, iterative counter if duplicates
                                                     # csvfile = os.path.join(outputfo, sqlcmd['save'])
@@ -1321,6 +1315,8 @@ class tdcoa:
         self.utils.log('upload_to_transcend started', header=True)
         self.utils.log('time', str(dt.datetime.now()))
 
+        skip_dbs = self.utils.validate_boolean(self.settings['skip_dbs'],'bool')
+
         # process 3 ways to get output path
         if _outputpath != '':  # use supplied path
             outputpath = _outputpath
@@ -1366,7 +1362,7 @@ class tdcoa:
         transcend = self.utils.open_connection(
             'teradataml',
             system=self.transcend,
-            skip = self.skip_dbs)  # <--------------------------------- Connect
+            skip = skip_dbs)  # <--------------------------------- Connect
 
         # Walk the directory structure looking for upload_manifest.json files
         for workpath, subfo, files in os.walk(outputpath):
@@ -1432,13 +1428,13 @@ class tdcoa:
                                     self.utils.log('perm table', entry['schema'] + '.' + entry['table'] + '_%s' % self.unique_id)
 
                                     # create staging table (perm) with unique id
-                                    if not self.skip_dbs:
+                                    if not skip_dbs:
                                         copy_to_sql(dfcsv, entry['table'] + '_%s' % self.unique_id, entry['schema'], if_exists='replace')
                                     self.utils.log('complete', str(dt.datetime.now()))
 
                                     # load to GTT
                                     self.utils.log('\nload to GTT', entry['schema'] + '.' + entry['table'])
-                                    if not self.skip_dbs:
+                                    if not skip_dbs:
                                         transcend['connection'].execute("""
                                         INSERT INTO {db}.{table} SELECT * FROM {db}.{unique_table}
                                         """.format(db=entry['schema'],
@@ -1454,7 +1450,7 @@ class tdcoa:
                                 # 2. call sp on GTT to merge to final table
                                 else:
                                     self.utils.log('write_to_perm', 'False')
-                                    if not self.skip_dbs:
+                                    if not skip_dbs:
                                         copy_to_sql(dfcsv, entry['table'], entry['schema'], if_exists='append')
                                     self.utils.log('complete', str(dt.datetime.now()))
                                     successful_load = True
@@ -1483,7 +1479,7 @@ class tdcoa:
                             if str(entry['call']).strip() != "" and successful_load:
                                 self.utils.log('\nStored Proc', str(entry['call']))
                                 try:
-                                    if not self.skip_dbs:
+                                    if not skip_dbs:
                                         transcend['connection'].execute('call %s ;' % str(entry['call']))
                                     self.utils.log('complete', str(dt.datetime.now()))
 
@@ -1491,7 +1487,7 @@ class tdcoa:
                                     if self.settings['write_to_perm'].lower() == 'true':
                                         self.utils.log('\ndrop unique perm table', entry['schema'] + '.' + entry['table'] + '_%s' % self.unique_id)
 
-                                        if not self.skip_dbs:
+                                        if not skip_dbs:
                                             transcend['connection'].execute("""
                                             DROP TABLE {db}.{unique_table}
                                             """.format(db=entry['schema'],
